package fr.exemples.gproducts

class ProduitController {

    static allowedMethods = [save: "POST", update: "POST", delete: "POST"]

    def index = {
        redirect(action: "list", params: params)
    }

    def list = {
        params.max = Math.min(params.max ? params.int('max') : 10, 100)
        [produitInstanceList: Produit.list(params), produitInstanceTotal: Produit.count()]
    }

    def create = {
        def produitInstance = new Produit()
        produitInstance.properties = params
        return [produitInstance: produitInstance]
    }

    def save = {
        def produitInstance = new Produit(params)
        if (produitInstance.save(flush: true)) {
            flash.message = "${message(code: 'default.created.message', args: [message(code: 'produit.label', default: 'Produit'), produitInstance.id])}"
            redirect(action: "show", id: produitInstance.id)
        }
        else {
            render(view: "create", model: [produitInstance: produitInstance])
        }
    }

    def show = {
        def produitInstance = Produit.get(params.id)
        if (!produitInstance) {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'produit.label', default: 'Produit'), params.id])}"
            redirect(action: "list")
        }
        else {
            [produitInstance: produitInstance]
        }
    }

    def edit = {
        def produitInstance = Produit.get(params.id)
        if (!produitInstance) {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'produit.label', default: 'Produit'), params.id])}"
            redirect(action: "list")
        }
        else {
            return [produitInstance: produitInstance]
        }
    }

    def update = {
        def produitInstance = Produit.get(params.id)
        if (produitInstance) {
            if (params.version) {
                def version = params.version.toLong()
                if (produitInstance.version > version) {
                    
                    produitInstance.errors.rejectValue("version", "default.optimistic.locking.failure", [message(code: 'produit.label', default: 'Produit')] as Object[], "Another user has updated this Produit while you were editing")
                    render(view: "edit", model: [produitInstance: produitInstance])
                    return
                }
            }
            produitInstance.properties = params
            if (!produitInstance.hasErrors() && produitInstance.save(flush: true)) {
                flash.message = "${message(code: 'default.updated.message', args: [message(code: 'produit.label', default: 'Produit'), produitInstance.id])}"
                redirect(action: "show", id: produitInstance.id)
            }
            else {
                render(view: "edit", model: [produitInstance: produitInstance])
            }
        }
        else {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'produit.label', default: 'Produit'), params.id])}"
            redirect(action: "list")
        }
    }

    def delete = {
        def produitInstance = Produit.get(params.id)
        if (produitInstance) {
            try {
                produitInstance.delete(flush: true)
                flash.message = "${message(code: 'default.deleted.message', args: [message(code: 'produit.label', default: 'Produit'), params.id])}"
                redirect(action: "list")
            }
            catch (org.springframework.dao.DataIntegrityViolationException e) {
                flash.message = "${message(code: 'default.not.deleted.message', args: [message(code: 'produit.label', default: 'Produit'), params.id])}"
                redirect(action: "show", id: params.id)
            }
        }
        else {
            flash.message = "${message(code: 'default.not.found.message', args: [message(code: 'produit.label', default: 'Produit'), params.id])}"
            redirect(action: "list")
        }
    }
}
